# similarity-based-rs

Package for obtaining content based recommendations based on similarity

## Installation

`pip install similarity-based-rs`

## Usage

TODO

## Dev Installation

For development purposes, additional libraries must be installed such as `pytest` and `mkdocs`.

Prerequisites:

* Python >=3.8 (we use `python3.11`)
* [Poetry](https://python-poetry.org/docs/#installation)
* [PreCommit](https://pre-commit.com/#install) (Optional)

**Steps**

```bash
1. Clone the repository or import it via your IDE
2. poetry install
3. pre-commit install (Optional)
4. git branch new_dev_branch_name
```
